@@ -4,7 +4,7 @@ package Test::Class::Moose::Role::Executor;
 
 use 5.10.0;
 
-our $VERSION = '0.69';
+our $VERSION = '0.70';
 
 use Moose::Role 2.0000;
 use Carp;
@@ -52,6 +52,9 @@ sub _tcm_run_test_instance {
     my $builder = $config->builder;
     my $report  = $self->test_report;
 
+    local $0 = "$0 - $test_instance_name"
+      if $config->set_process_name;
+
     # set up test class reporting
     my $instance_report = Test::Class::Moose::Report::Instance->new(
         {   name => $test_instance_name,
@@ -348,7 +351,7 @@ Test::Class::Moose::Role::Executor - Common code for Runner classes
 
 =head1 VERSION
 
-version 0.69
+version 0.70
 
 =for Pod::Coverage test_classes
 
